@@ -5,7 +5,7 @@ use warnings;
 
 use vars qw($VERSION);
 BEGIN {
-  $VERSION='2.16'; # version template
+  $VERSION='2.18'; # version template
 }
 no warnings 'uninitialized';
 use Carp;
@@ -196,9 +196,9 @@ sub validate_object {
 	    if ($flags & PML_VALIDATE_NO_CHILDNODES) {
 	      $skip_content = 1;
 	    } elsif ($cdecl_is == PML_SEQUENCE_DECL) {
-	      $content = Treex::PML::FSFactory->createSeq([map { Treex::PML::Seq::Element->new($_->{'#name'},$_) } $object->children]);
+	      $content = Treex::PML::Factory->createSeq([map { Treex::PML::Seq::Element->new($_->{'#name'},$_) } $object->children]);
 	    } elsif ($cdecl_is == PML_LIST_DECL) {
-	      $content = Treex::PML::FSFactory->createList([$object->children],1);
+	      $content = Treex::PML::Factory->createList([$object->children],1);
 	    } else {
 	      push @$log, "$path: #CHILDNODES should be either a list or sequence";
 	    }
